==> better_hypixel_chat-0.1.1%2B1.21.5-sources.jar: io/github/viciscat/bhc/TextBuilder.java <==
package io.github.viciscat.bhc;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_5224;
import net.minecraft.class_5250;

public class TextBuilder implements class_5224 {
    private final List<class_5250> texts = new ArrayList<>();
    private class_2583 style = null;
    private final StringBuilder stringBuilder = new StringBuilder();

    public TextBuilder() {
        texts.add(class_2561.method_43473());
    }

    @Override
    public boolean accept(int index, class_2583 style, int codePoint) {
        if (this.style == null) this.style = style;

        if (!this.style.equals(style)) {
            if (!stringBuilder.isEmpty()) {
                texts.getLast().method_10852(class_2561.method_43470(stringBuilder.toString()).method_10862(this.style));
                stringBuilder.setLength(0);
            }
            this.style = style;
        }
        if (codePoint == '\n') {
            if (!stringBuilder.isEmpty()) {
                texts.getLast().method_10852(class_2561.method_43470(stringBuilder.toString()).method_10862(this.style));
                stringBuilder.setLength(0);
            }
            texts.add(class_2561.method_43473());
            return true;
        }
        stringBuilder.append(Character.toChars(codePoint));
        return true;
    }

    public Collection<class_5250> getTexts() {
        if (!stringBuilder.isEmpty()) {
            texts.getLast().method_10852(class_2561.method_43470(stringBuilder.toString()).method_10862(this.style));
        }
        return texts;
    }
}

==> better_hypixel_chat-0.2.1%2B1.21.8-sources.jar: io/github/viciscat/bhc/TextBuilder.java <==
package io.github.viciscat.bhc;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_5224;
import net.minecraft.class_5250;

public class TextBuilder implements class_5224 {
    private final List<class_5250> texts = new ArrayList<>();
    private class_2583 style = null;
    private final StringBuilder stringBuilder = new StringBuilder();
    private final int start;
    private final int end;
    private int i = -1;

    public TextBuilder(int start, int end) {
        this.start = start;
        this.end = end;
        texts.add(class_2561.method_43473());
    }

    public TextBuilder() {
        this(0, Integer.MAX_VALUE);
    }

    @Override
    public boolean accept(int index, class_2583 style, int codePoint) {
        i++;
        if (i < start || i > end) return true;
        if (this.style == null) this.style = style;

        if (!this.style.equals(style)) {
            if (!stringBuilder.isEmpty()) {
                texts.getLast().method_10852(class_2561.method_43470(stringBuilder.toString()).method_10862(this.style));
                stringBuilder.setLength(0);
            }
            this.style = style;
        }
        if (codePoint == '\n') {
            if (!stringBuilder.isEmpty()) {
                texts.getLast().method_10852(class_2561.method_43470(stringBuilder.toString()).method_10862(this.style));
                stringBuilder.setLength(0);
            }
            texts.add(class_2561.method_43473());
            return true;
        }
        stringBuilder.append(Character.toChars(codePoint));
        return true;
    }

    public List<class_5250> getTexts() {
        if (!stringBuilder.isEmpty()) {
            texts.getLast().method_10852(class_2561.method_43470(stringBuilder.toString()).method_10862(this.style));
        }
        return texts;
    }
}
